==> owncloud-app-documents-1%3A9.0.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/sq.js <==
OC.L10N.register(
    "documents",
    {
    "Documents" : "Dokumente",
    "Can't create document" : "S’krijohet dot dokumenti",
    "You don't have permission to rename this document" : "Nuk keni leje të riemërtoni këtë dokument",
    "Directory saved successfully." : "Drejtoria u ruajt me sukses.",
    "An error occurred while changing directory." : "Ndodhi një gabim gjatë ndryshimit të drejtorisë.",
    "Saved" : "U ruajt",
    "Format filter server is down or misconfigured" : "Shërbyesi i filtrave të formatit është jashtë funksionimi ose i keqformësuar",
    "Conversion failed. Check log for details." : "Shndërrimi dështoi. Për hollësi, kontrolloni regjistrin.",
    "Saving..." : "Po ruhet…",
    "Failed to load documents." : "Dështoi në ngarkim dokumentesh.",
    "No documents were found. Upload or create a document to get started!" : "S’u gjetën dokumente. Ngarkoni ose krijoni një dokument që t’ia fillohet!",
    "No connection to server. Trying to reconnect." : "Pa lidhje me shërbyesin. Po provohet të rilidhet.",
    "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." : "Largimi nga faqja duke qenë ende nën Mënyrën Përpunues mund të prodhojë mosruajtje të dhënash. Në vend të kësaj, këshillohet të përdorni butonin 'Mbylle'.",
    "Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." : "Dështoi ngarkimi i këtij dokumenti. Ju lutemi, kontrolloni nëse mund të hapet me një përpunues tekstesh të vjetër, të jashtëm. Kjo mund të nënkuptojë që është hequr nga ndarje ose është fshirë tani afër.",
    "Save" : "Ruaje",
    "Loading documents..." : "Po ngarkohen dokumente…",
    "'.' is an invalid file name." : "'.' është emër i pavlefshëm kartele.",
    "File name cannot be empty." : "Emri i kartelës s’mund të jetë i zbrazët.",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "Emër i pavlefshëm, '\\', '/', '<', '>', ':', '\"', '|', '?' dhe '*' nuk lejohen.",
    "Align Left" : "Vendose Majtas",
    "Alignment" : "Drejtim",
    "Align Right" : "Vendose Djathtas",
    "Annotate" : "I vini shënim",
    "Background" : "Sfond",
    "Bold" : "Të trasha",
    "Bottom" : "Poshtë",
    "Cancel" : "Anuloje",
    "Center" : "Në Qendër",
    "Clone" : "Klonojeni",
    "Clone this Style" : "Klonojeni me Stil",
    "Close" : "Mbylle",
    "Color" : "Ngjyrë",
    "Create" : "Krijoje",
    "Decrease Indent" : "Pakësoje Shmangien",
    "Default Style" : "Stil Parazgjedhje",
    "Delete" : "Fshije",
    "Family" : "Familje",
    "Font" : "Shkronja",
    "Font Effects" : "Efekte Shkronjash",
    "Format" : "Format",
    "Increase Indent" : "Shtoje Shmangien",
    "Insert Image" : "Futni Figurë",
    "Invite Members" : "Ftoni Anëtarë",
    "Italic" : "Të pjerrta",
    "Justified" : "Të përligjura",
    "Justify" : "Përligje",
    "Left" : "Majtas",
    "Loading" : "Ngarkim",
    "Members" : "Anëtarë",
    "New Name:" : "Emër i Ri:",
    "OK" : "OK",
    "Open" : "Hape",
    "Options" : "Mundësi",
    "Paragraph..." : "Paragraf…",
    "Paragraph Styles" : "Stile Paragrafi",
    "Redo" : "Ribëje",
    "Right" : "Djathtas",
    "Size" : "Madhësi",
    "Spacing" : "Hapësirë",
    "Strikethrough" : "Hequrvije",
    "Style" : "Stil",
    "Text" : "Tekst",
    "Top" : "Sipër",
    "Underline" : "Të nënvizuara",
    "Undo" : "Zhbëje",
    "Unknown Author" : "Autor i Panjohur",
    "Shared" : "E ndarë",
    "Error" : "Gabim",
    "Error while sharing" : "Gabim gjatë ndarjes",
    "Error while unsharing" : "Gabim gjatë heqjes së ndarjes",
    "Error while changing permissions" : "Gabim gjatë ndryshimit të lejeve",
    "Shared with you and the group {group} by {owner}" : "Ndarë me ju dhe me grupin {group} nga {owner}",
    "Shared with you by {owner}" : "Ndarë me ju nga {owner}",
    "Share with users or groups …" : "Ndajeni me përdorues ose grupe …",
    "Share with users, groups or remote users …" : "Ndajeni me përdorues, grupe ose përdorues të largët …",
    "Share" : "Ndaje",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Ndajeni me persona në ownCloud-e të tjera duke përdorur sintaksën username@example.com/owncloud",
    "Share link" : "Lidhje ndarjeje",
    "The public link will expire no later than {days} days after it is created" : "Lidhja publike do të skadojë jo më vonë se {days} ditë pas krijimit",
    "Link" : "Lidhje",
    "Password protect" : "Mbroje me fjalëkalim",
    "Password" : "Fjalëkalim",
    "Choose a password for the public link" : "Zgjidhni një fjalëkalim për lidhjen publike",
    "Allow editing" : "Lejo përpunim",
    "Email link to person" : "Dërgoji personit email me lidhjen",
    "Send" : "Dërgoje",
    "Set expiration date" : "Caktoni datë skadimi",
    "Expiration" : "Skadim",
    "Expiration date" : "Datë skadimi",
    "An error occured. Please try again" : "Ndodhi një gabim. Ju lutemi, riprovoni",
    "Adding user..." : "Po shtohet përdorues…",
    "group" : "grup",
    "remote" : "e largët",
    "Resharing is not allowed" : "Nuk lejohen rindarjet",
    "Shared in {item} with {user}" : "Ndarë në {item} me {user}",
    "Unshare" : "Hiqe ndarjen",
    "notify by email" : "njofto me email",
    "can share" : "mund të ndajë",
    "can edit" : "mund të ndryshojë",
    "access control" : "kontroll hyrjesh",
    "create" : "krijo",
    "change" : "ndrysho",
    "delete" : "fshije",
    "Password protected" : "Mbrojtur me fjalëkalim",
    "Error unsetting expiration date" : "Gabim gjatë heqjes së datës së skadimit",
    "Error setting expiration date" : "Gabim gjatë caktimit të datës së skadimit",
    "Sending ..." : "Po dërgohet …",
    "Email sent" : "Email-i u dërgua",
    "Warning" : "Kujdes",
    "Edit" : "Përpunoni",
    "guest" : "vizitor",
    "MS Word support (requires openOffice/libreOffice)" : "Mbulim i MS Word-it (lyp openOffice/libreOffice)",
    "Local" : "Vendor",
    "openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" : "openOffice/libreOffice është i instaluar në këtë shërbyes. Shtegu për te dyori jepet përmes preview_libreoffice_path te config.php",
    "External" : "I jashtëm",
    "openOffice/libreOffice is installed on external server running a format filter server" : "openOffice/libreOffice is installed on external server running a format filter serveropenOffice/libreOffice është i instaluar në një shërbyes të jashtëm që xhiron një shërbyes filtrash formati",
    "Disabled" : "I çaktivizuar",
    "No MS Word support" : "S’ka mbulim të MS Word-it",
    "scheme://domain.tld[:port]" : "scheme://domain.tld[:port]",
    "Server URL" : "URL shërbyesi",
    "Apply and test" : "Zbatoje dhe testoje",
    "New document" : "Dokument i ri",
    "Upload (max. %s)" : "Ngarkim (max. %s)",
    "Upload" : "Ngarkoje",
    "Save new documents to" : "Dokumentet e reja ruaji te",
    "Wrong password. Please retry." : "Fjalëkalim gabuar. Ju lutemi, riprovoni.",
    "Guest %s" : "Vizitori %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Kjo lidhje ka skaduar ose s’ka ekzistuar kurrë. Ju lutemi, për hollësi, lidhuni me personin që e ndau atë me ju.",
    "(Unstable)" : "(E paqëndrueshme)"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-app-documents-1%3A9.1.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/sq.js <==
OC.L10N.register(
    "documents",
    {
    "Documents" : "Dokumente",
    "Can't create document" : "S’krijohet dot dokumenti",
    "You don't have permission to rename this document" : "Nuk keni leje të riemërtoni këtë dokument",
    "File does not exist" : "S’ka kartelë të tillë",
    "Directory saved successfully." : "Drejtoria u ruajt me sukses.",
    "An error occurred while changing directory." : "Ndodhi një gabim gjatë ndryshimit të drejtorisë.",
    "Saved" : "U ruajt",
    "Format filter server is down or misconfigured" : "Shërbyesi i filtrave të formatit është jashtë funksionimi ose i keqformësuar",
    "Conversion failed. Check log for details." : "Shndërrimi dështoi. Për hollësi, kontrolloni regjistrin.",
    "Saving..." : "Po ruhet…",
    "Failed to load documents." : "Dështoi në ngarkim dokumentesh.",
    "No documents were found. Upload or create a document to get started!" : "S’u gjetën dokumente. Ngarkoni ose krijoni një dokument që t’ia fillohet!",
    "No connection to server. Trying to reconnect." : "Pa lidhje me shërbyesin. Po provohet të rilidhet.",
    "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." : "Largimi nga faqja duke qenë ende nën Mënyrën Përpunues mund të prodhojë mosruajtje të dhënash. Në vend të kësaj, këshillohet të përdorni butonin 'Mbylle'.",
    "Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." : "Dështoi ngarkimi i këtij dokumenti. Ju lutemi, kontrolloni nëse mund të hapet me një përpunues tekstesh të vjetër, të jashtëm. Kjo mund të nënkuptojë që është hequr nga ndarje ose është fshirë tani afër.",
    "Save" : "Ruaje",
    "Loading documents..." : "Po ngarkohen dokumente…",
    "'.' is an invalid file name." : "'.' është emër i pavlefshëm kartele.",
    "File name cannot be empty." : "Emri i kartelës s’mund të jetë i zbrazët.",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "Emër i pavlefshëm, '\\', '/', '<', '>', ':', '\"', '|', '?' dhe '*' nuk lejohen.",
    "Align Left" : "Vendose Majtas",
    "Alignment" : "Drejtim",
    "Align Right" : "Vendose Djathtas",
    "Annotate" : "I vini shënim",
    "Background" : "Sfond",
    "Bold" : "Të trasha",
    "Bottom" : "Poshtë",
    "Cancel" : "Anuloje",
    "Center" : "Në Qendër",
    "Clone" : "Klonojeni",
    "Clone this Style" : "Klonojeni me Stil",
    "Close" : "Mbylle",
    "Color" : "Ngjyrë",
    "Create" : "Krijoje",
    "Decrease Indent" : "Pakësoje Shmangien",
    "Default Style" : "Stil Parazgjedhje",
    "Delete" : "Fshije",
    "Family" : "Familje",
    "Font" : "Shkronja",
    "Font Effects" : "Efekte Shkronjash",
    "Format" : "Format",
    "Increase Indent" : "Shtoje Shmangien",
    "Insert Image" : "Futni Figurë",
    "Invite Members" : "Ftoni Anëtarë",
    "Italic" : "Të pjerrta",
    "Justified" : "Të përligjura",
    "Justify" : "Përligje",
    "Left" : "Majtas",
    "Loading" : "Ngarkim",
    "Members" : "Anëtarë",
    "New Name:" : "Emër i Ri:",
    "OK" : "OK",
    "Open" : "Hape",
    "Options" : "Mundësi",
    "Paragraph..." : "Paragraf…",
    "Paragraph Styles" : "Stile Paragrafi",
    "Redo" : "Ribëje",
    "Right" : "Djathtas",
    "Size" : "Madhësi",
    "Spacing" : "Hapësirë",
    "Strikethrough" : "Hequrvije",
    "Style" : "Stil",
    "Text" : "Tekst",
    "Top" : "Sipër",
    "Underline" : "Të nënvizuara",
    "Undo" : "Zhbëje",
    "Unknown Author" : "Autor i Panjohur",
    "Shared" : "E ndarë",
    "Error" : "Gabim",
    "Error while sharing" : "Gabim gjatë ndarjes",
    "Error while unsharing" : "Gabim gjatë heqjes së ndarjes",
    "Error while changing permissions" : "Gabim gjatë ndryshimit të lejeve",
    "Shared with you and the group {group} by {owner}" : "Ndarë me ju dhe me grupin {group} nga {owner}",
    "Shared with you by {owner}" : "Ndarë me ju nga {owner}",
    "Share with users or groups …" : "Ndajeni me përdorues ose grupe …",
    "Share with users, groups or remote users …" : "Ndajeni me përdorues, grupe ose përdorues të largët …",
    "Share" : "Ndaje",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Ndajeni me persona në ownCloud-e të tjera duke përdorur sintaksën username@example.com/owncloud",
    "Share link" : "Lidhje ndarjeje",
    "The public link will expire no later than {days} days after it is created" : "Lidhja publike do të skadojë jo më vonë se {days} ditë pas krijimit",
    "Link" : "Lidhje",
    "Password protect" : "Mbroje me fjalëkalim",
    "Password" : "Fjalëkalim",
    "Choose a password for the public link" : "Zgjidhni një fjalëkalim për lidhjen publike",
    "Allow editing" : "Lejo përpunim",
    "Email link to person" : "Dërgoji personit email me lidhjen",
    "Send" : "Dërgoje",
    "Set expiration date" : "Caktoni datë skadimi",
    "Expiration" : "Skadim",
    "Expiration date" : "Datë skadimi",
    "An error occured. Please try again" : "Ndodhi një gabim. Ju lutemi, riprovoni",
    "Adding user..." : "Po shtohet përdorues…",
    "group" : "grup",
    "remote" : "e largët",
    "Resharing is not allowed" : "Nuk lejohen rindarjet",
    "Shared in {item} with {user}" : "Ndarë në {item} me {user}",
    "Unshare" : "Hiqe ndarjen",
    "notify by email" : "njofto me email",
    "can share" : "mund të ndajë",
    "can edit" : "mund të ndryshojë",
    "access control" : "kontroll hyrjesh",
    "create" : "krijo",
    "change" : "ndrysho",
    "delete" : "fshije",
    "Password protected" : "Mbrojtur me fjalëkalim",
    "Error unsetting expiration date" : "Gabim gjatë heqjes së datës së skadimit",
    "Error setting expiration date" : "Gabim gjatë caktimit të datës së skadimit",
    "Sending ..." : "Po dërgohet …",
    "Email sent" : "Email-i u dërgua",
    "Warning" : "Kujdes",
    "Edit" : "Përpunoni",
    "guest" : "vizitor",
    "MS Word support (requires openOffice/libreOffice)" : "Mbulim i MS Word-it (lyp openOffice/libreOffice)",
    "Local" : "Vendor",
    "openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" : "openOffice/libreOffice është i instaluar në këtë shërbyes. Shtegu për te dyori jepet përmes preview_libreoffice_path te config.php",
    "External" : "I jashtëm",
    "openOffice/libreOffice is installed on external server running a format filter server" : "openOffice/libreOffice is installed on external server running a format filter serveropenOffice/libreOffice është i instaluar në një shërbyes të jashtëm që xhiron një shërbyes filtrash formati",
    "Disabled" : "I çaktivizuar",
    "No MS Word support" : "S’ka mbulim të MS Word-it",
    "scheme://domain.tld[:port]" : "scheme://domain.tld[:port]",
    "Server URL" : "URL shërbyesi",
    "Apply and test" : "Zbatoje dhe testoje",
    "New document" : "Dokument i ri",
    "Upload (max. %s)" : "Ngarkim (max. %s)",
    "Upload" : "Ngarkoje",
    "Save new documents to" : "Dokumentet e reja ruaji te",
    "Wrong password. Please retry." : "Fjalëkalim gabuar. Ju lutemi, riprovoni.",
    "Guest %s" : "Vizitori %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Kjo lidhje ka skaduar ose s’ka ekzistuar kurrë. Ju lutemi, për hollësi, lidhuni me personin që e ndau atë me ju.",
    "Advanced feature-set" : "Grup veçorish të thelluara",
    "(Unstable)" : "(E paqëndrueshme)"
},
"nplurals=2; plural=(n != 1);");
